@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #############################################################################
 #  Copyright Kitware Inc.
 #
@@ -18,10 +16,13 @@
 
 import datetime
 import json
-import six
+
+from girder_jobs.constants import JobStatus
+from girder_jobs.models.job import Job
 from pkg_resources import DistributionNotFound, get_distribution
 
 import girder
+import large_image
 from girder import events
 from girder.constants import AccessType
 from girder.exceptions import ValidationException
@@ -31,23 +32,16 @@ from girder.models.notification import Notification
 from girder.models.setting import Setting
 from girder.plugin import GirderPlugin, getPlugin
 from girder.settings import SettingDefault
-from girder.utility import config
-from girder.utility import setting_utilities
+from girder.utility import config, setting_utilities
 from girder.utility.model_importer import ModelImporter
-from girder_jobs.constants import JobStatus
-from girder_jobs.models.job import Job
 
-import large_image
-
-from . import constants
-from . import girder_tilesource
+from . import constants, girder_tilesource
 from .girder_tilesource import getGirderTileSource  # noqa
 from .loadmodelcache import invalidateLoadModelCache
 from .models.image_item import ImageItem
 from .rest.large_image_resource import LargeImageResource
 from .rest.tiles import TilesItemResource
 
-
 try:
     __version__ = get_distribution(__name__).version
 except DistributionNotFound:
@@ -77,6 +71,8 @@ def _postUpload(event):
         del item['largeImage']['expected']
         item['largeImage']['fileId'] = fileObj['_id']
         item['largeImage']['sourceName'] = 'tiff'
+        if fileObj['name'].endswith('.geo.tiff'):
+            item['largeImage']['sourceName'] = 'gdal'
         Item().save(item)
 
 
@@ -104,6 +100,8 @@ def _updateJob(event):
         # don't clear the expected status on success.
         if status != JobStatus.SUCCESS:
             del item['largeImage']['expected']
+        else:
+            return
     notify = item.get('largeImage', {}).get('notify')
     msg = None
     if notify:
@@ -143,9 +141,10 @@ def checkForLargeImageFiles(event):
     exts = [ext.split()[0] for ext in file.get('exts') if ext]
     if set(exts[-2:]).intersection(girder_tilesource.KnownExtensions):
         possible = True
-    if not file.get('itemId') or not possible:
+    if not file.get('itemId'):
         return
-    if not Setting().get(constants.PluginSettings.LARGE_IMAGE_AUTO_SET):
+    autoset = Setting().get(constants.PluginSettings.LARGE_IMAGE_AUTO_SET)
+    if not autoset or (not possible and autoset != 'all'):
         return
     item = Item().load(file['itemId'], force=True, exc=False)
     if not item or item.get('largeImage'):
@@ -210,7 +209,6 @@ def handleRemoveFile(event):
 @setting_utilities.validator({
     constants.PluginSettings.LARGE_IMAGE_SHOW_THUMBNAILS,
     constants.PluginSettings.LARGE_IMAGE_SHOW_VIEWER,
-    constants.PluginSettings.LARGE_IMAGE_AUTO_SET,
 })
 def validateBoolean(doc):
     val = doc['value']
@@ -219,6 +217,16 @@ def validateBoolean(doc):
     doc['value'] = (str(val).lower() != 'false')
 
 
+@setting_utilities.validator({
+    constants.PluginSettings.LARGE_IMAGE_AUTO_SET,
+})
+def validateBooleanOrAll(doc):
+    val = doc['value']
+    if str(val).lower() not in ('false', 'true', 'all', ''):
+        raise ValidationException('%s must be a boolean or "all".' % doc['key'], 'value')
+    doc['value'] = val if val in {'all'} else (str(val).lower() != 'false')
+
+
 @setting_utilities.validator({
     constants.PluginSettings.LARGE_IMAGE_SHOW_EXTRA_PUBLIC,
     constants.PluginSettings.LARGE_IMAGE_SHOW_EXTRA,
@@ -298,7 +306,7 @@ class LargeImagePlugin(GirderPlugin):
         large_image.config.setConfig('logprint', girder.logprint)
         # Load girder's large_image config
         curConfig = config.getConfig().get('large_image')
-        for key, value in six.iteritems(curConfig or {}):
+        for key, value in (curConfig or {}).items():
             large_image.config.setConfig(key, value)
 
         girder_tilesource.loadGirderTileSources()
